@@ -24,7 +24,7 @@ class QueryParser(ABC):
 
     def __init__(
         self,
-        valid_columns: list[str],
+        valid_columns: Iterable[str],
         *,
         default_operator_factory: Callable[[str], FiltrationOperator],
         available_operators_factory: Callable[[str], list[FiltrationOperator]],
@@ -139,6 +139,10 @@ class LHSQueryParser(QueryParser):
                     f"Available ones: {filtrations_possible_str}",
                 )
 
+            # Wildcard operator should work for each column
+            if key_data == "*":
+                return {col: [(key_filter, value)] for col in self._valid_columns}
+
             return {key_data: [(key_filter, value)]}
 
         # Otherwise it will be considered an equality filter
@@ -185,6 +189,24 @@ class LHSQueryParser(QueryParser):
             )
             new_parameters.append(param)
 
+            param = inspect.Parameter(
+                name="__wildcard__",
+                kind=inspect.Parameter.KEYWORD_ONLY,
+                annotation=Optional[str],
+                default=Query(
+                    None,
+                    alias=f"*[<FilterOperator>]",
+                    title=f"Filtering by all columns",
+                    description="\n\n".join(
+                        [
+                            f"Available operators: {available_operators_str}",
+                            f"Default operator: `{default_operator.value}`",
+                        ]
+                    ),
+                ),
+            )
+            new_parameters.append(param)
+
         new_signature = old_signature.replace(parameters=new_parameters)
         setattr(func, "__signature__", new_signature)
         return func
